%%
clear
close all
rand('seed',1);
randn('seed',1);

%% Data
% training data

load 'mixtureexampleTRAIN.dat'
Xapp = mixtureexampleTRAIN(1:400);
Xapp = reshape(Xapp,200,2);
yapp = [ones(100,1);zeros(100,1)];
zapp = 2*yapp - 1;
n = length(yapp);

% test data

load 'mixtureexampleTEST1.dat'
Xt = mixtureexampleTEST1(1:2*6831);
Xt = reshape(Xt,6831,2);
load 'mixtureexamplePtest.dat';
yt = round(mixtureexamplePtest);
prob = mixtureexamplePtest;
nt = length(yt);

load 'mixtureexampleMarg.dat'
marg = mixtureexampleMarg;

%%

figure(1); 
set(gcf,'Color',[1,1,1])
plot(Xapp(yapp==1,1),Xapp(yapp==1,2),'+r'); hold on
plot(Xapp(yapp==0,1),Xapp(yapp==0,2),'xb'); 

%% Kernelization

kerneloption = .5;
[Kapp1] = kernel (Xapp, Xapp, kerneloption);
[Kapp2] = kernel (Xapp, Xapp, kerneloption/2);


%% Reg log initialization
N = 10000;                               % number maximum of iterations
X = [Kapp1 Kapp2 ones(n,1)];
[n,q] = size(X);

lambda = 1;
pas = 5*1/svds(X,1)^2;


w = my_reglog_l1 (X, yapp, pas, lambda, N);

sparse = 100*length(find(abs(w)>sqrt(eps)))/q;
sizew = length(find(abs(w)>sqrt(eps)));

%% error probabilits


[Kt1] = kernel (Xt, Xapp, kerneloption);
[Kt2] = kernel (Xt, Xapp, kerneloption/2);
Xt = [Kt1 Kt2 ones(nt,1)];
ypred = (1./(1+exp(-Xt*w)));

ind1 = find(ypred > 0.5);
probT = 1-prob;
probT(ind1) = prob(ind1);
perrRL = sum(marg.*probT);


bayes_error = sum(marg.*(prob.*(prob<0.5)+(1-prob).*(prob>=.5)));
fprintf('Bayes: %5.2f%% RegLog: %5.2f%%   non 0 components: %5.2f%%  %5d\n',[100*bayes_error 100*perrRL sparse sizew])



%% do the nice plot

[xtest1 xtest2]  = meshgrid([-1:.05:1.2]*3.5+.5,[-1:0.05:1]*3); 
[nn mm] = size(xtest1); 
Xtest = [reshape(xtest1 ,nn*mm,1) reshape(xtest2 ,nn*mm,1)]; 

nt = length(Xtest);
[Kt1] = kernel (Xtest, Xapp, kerneloption);
[Kt2] = kernel (Xtest, Xapp, kerneloption/2);
Xt = [Kt1 Kt2 ones(nt,1)];
ypred = (1./(1+exp(-Xt*w)));

ind1 = find(ypred > 0.5);
probT = 1-prob;
probT(ind1) = prob(ind1);
perr = sum(marg.*probT);


ypred = reshape(ypred,nn,mm); 

figure(1); 
contourf(xtest1,xtest2,(ypred),50);shading flat;hold on; 
plot(Xapp(yapp==1,1),Xapp(yapp==1,2),'+r'); hold on
plot(Xapp(yapp==0,1),Xapp(yapp==0,2),'xb'); 
[cc, hh]=contour(xtest1,xtest2,ypred,[-100000 0.5],'w','LineWidth',4); 
clabel(cc,hh); 
axis([-3. 4 -3 3])


